import { useCountryInfoStore } from '/@/stores/countryInfo';
import { useResponse } from '/@/utils/useResponse';
import * as api from '/@/views/shop-information/api';


const countryInfoStore = useCountryInfoStore();

export const companySelect: Ref<any[]> = ref([]);
// const ret = await useResponse({}, api.getCompanySelect);
// companySelect.value = ret.data;

async function main() {
  const result = await api.getCompanySelect();
  companySelect.value = result.data;
}

main();

export const platformColumns = [
  { type: 'seq', title: '序 号', width: 60, align: 'center', fixed: 'left' },
  {
    field: 'operatorName', title: '运 营', minWidth: 'auto', align: 'center', fixed: 'left',
    slots: {
      default({ row }: any) {
        return <span class={ 'font-medium' }>{ row.operatorName ? row.operatorName : '--' }</span>;
      }
    }
  },
  {
    field: 'platformNumber', title: '店铺编号', minWidth: 'auto', align: 'center', slots: { default: 'platformNumber' }
  },
  {
    field: 'platformName', title: '店铺名称', minWidth: 'auto', align: 'center', slots: {
      default({ row }: any) {
        return <span class={ 'font-medium' }
                     style={ { color: '#303133' } }>{ row.platformName ? row.platformName : '--' }</span>;
      }
    }
  },
  {
    field: 'country', title: '国 家', minWidth: 'auto', align: 'center',
    slots: {
      default({ row }: any) {
        const country = countryInfoStore.countries.find(c => c.name === row.country);
        const color = country ? country.color : '#3875F6';
        return <el-tag effect="plain" round
                       style={ { color: color, borderColor: color } }>{ row.country ? row.country : '--' }</el-tag>;
      }
    }
  },
  {
    field: 'brandName', title: '品牌名称', minWidth: 'auto', align: 'center',
    slots: {
      default({ row }: any) {
        return <span class={ 'font-medium' }>{ row.brandName ? row.brandName : '--' }</span>;
      }
    }
  },
  {
    field: 'currencyCode', title: '货币代码', minWidth: 'auto', align: 'center',
    slots: {
      default({ row }: any) {
        return <span class={ 'font-medium' }>{ row.currencyCode ? row.currencyCode : '--' }</span>;
      }
    }
  },
  {
    field: 'status', title: '状 态', minWidth: 'auto', align: 'center',
    slots: {
      default({ row }: any) {
        return (
            <el-tag
                class="font-medium"
                type={ row.status === 1 ? 'success' : 'danger' }   // 动态绑定 type
            >
              { row.status === 1 ? '启用' : '暂停' }
            </el-tag>
        );
      }
    }
  },
  {
    field: 'platform', title: '平 台', minWidth: 'auto', align: 'center',
    slots: {
      default({ row }: any) {
        return <span class={ 'font-medium' }>{ row.platform ? row.platform : '--' }</span>;
      }
    }
  },
  {
    field: 'line', title: '线 路', minWidth: 'auto', align: 'center',
    slots: {
      default({ row }: any) {
        return <span class={ 'font-medium' }>{ row.line ? row.line : '--' }</span>;
      }
    }
  },
  {
    field: 'ipaddress', title: 'IP地址', minWidth: 'auto', align: 'center',
    slots: {
      default({ row }: any) {
        return <span class={ 'font-medium' }>{ row.ipaddress ? row.ipaddress : '--' }</span>;
      }
    }
  },
  {
    field: 'company', title: '公司名称', minWidth: 'auto', align: 'center',
    slots: {
      default({ row }: any) {
        return <span class={ 'font-medium' }>{ row.company ? row.company : '--' }</span>;
      }
    }
  },
  {
    field: 'companyEnglishName', title: '公司英文名称', minWidth: 'auto', align: 'center',
    slots: {
      default({ row }: any) {
        return <span class={ 'font-medium' }>{ row.companyEnglishName ? row.companyEnglishName : '--' }</span>;
      }
    }
  },
  {
    field: 'address', title: '公司地址', minWidth: 'auto', align: 'center',
    slots: {
      default({ row }: any) {
        return <span class={ 'font-medium' }>{ row.address ? row.address : '--' }</span>;
      }
    }
  },
  {
    field: 'juridicalPerson', title: '法人', minWidth: 'auto', align: 'center',
    slots: {
      default({ row }: any) {
        return <span class={ 'font-medium' }>{ row.juridicalPerson ? row.juridicalPerson : '--' }</span>;
      }
    }
  },
  {
    field: 'juridicalPersonCreditCard', title: '法人信用卡', minWidth: 'auto', align: 'center',
    slots: {
      default({ row }: any) {
        return <span
            class={ 'font-medium' }>{ row.juridicalPersonCreditCard ? row.juridicalPersonCreditCard : '--' }</span>;
      }
    }
  },
  {
    field: 'juridicalPersonCreditCardAddress', title: '法人信用卡地址', minWidth: 'auto', align: 'center',
    slots: {
      default({ row }: any) {
        return <span
            class={ 'font-medium' }>{ row.juridicalPersonCreditCardAddress ? row.juridicalPersonCreditCardAddress : '--' }</span>;
      }
    }
  },
  {
    field: 'receivablesAccount', title: '收款账户', minWidth: 'auto', align: 'center',
    slots: {
      default({ row }: any) {
        return <span class={ 'font-medium' }>{ row.receivablesAccount ? row.receivablesAccount : '--' }</span>;
      }
    }
  },
  {
    field: 'receivablesAccountCompany', title: '收款账户公司', minWidth: 'auto', align: 'center',
    slots: {
      default({ row }: any) {
        return <span
            class={ 'font-medium' }>{ row.receivablesAccountCompany ? row.receivablesAccountCompany : '--' }</span>;
      }
    }
  },
  {
    field: 'vatNumber', title: 'VAT税号', minWidth: 200, align: 'center',
    slots: {
      default({ row }: any) {
        return <span class={ 'font-medium' }>{ row.vatNumber ? row.vatNumber : '--' }</span>;
      }
    }
  },
  {
    field: 'vatCompany', title: 'VAT公司', minWidth: 'auto', align: 'center',
    slots: {
      default({ row }: any) {
        return <span class={ 'font-medium' }>{ row.vatCompany ? row.vatCompany : '--' }</span>;
      }
    }
  },
  {
    field: 'shopPhoneEmail', title: '店铺电话与邮箱', minWidth: 'auto', align: 'center',
    slots: {
      default({ row }: any) {
        return <span class={ 'font-medium' }>{ row.shopPhoneEmail ? row.shopPhoneEmail : '--' }</span>;
      }
    }
  }
];

export const shopCurrentColumns = [
  { type: 'seq', title: '序 号', width: 60, align: 'center', fixed: 'left' },
  {
    field: 'operatorName', title: '运 营', minWidth: 'auto', align: 'center', fixed: 'left',
    slots: {
      default({ row }: any) {
        return <span class={ 'font-medium' }>{ row.operatorName ? row.operatorName : '--' }</span>;
      }
    }
  },
  {
    field: 'platformNumber', title: '店铺编号', minWidth: 'auto', align: 'center',
    slots: {
      default({ row }: any) {
        return <span class={ 'font-medium' }>{ row.platformNumber ? row.platformNumber : '--' }</span>;
      }
    }
  },
  {
    field: 'platformName', title: '店铺名称', minWidth: 'auto', align: 'center',
    slots: {
      default({ row }: any) {
        return <span class={ 'font-medium' }>{ row.platformName ? row.platformName : '--' }</span>;
      }
    }
  },
  {
    field: 'country', title: '国 家', minWidth: 'auto', align: 'center',
    slots: {
      default({ row }: any) {
        const country = countryInfoStore.countries.find(c => c.name === row.country);
        const color = country ? country.color : '#3875F6';
        return <el-tag effect="plain" round
                       style={ { color: color, borderColor: color } }>{ row.country ? row.country : '--' }</el-tag>;
      }
    }
  },
  {
    field: 'brandName', title: '品牌名称', minWidth: 'auto', align: 'center',
    slots: {
      default({ row }: any) {
        return <span class={ 'font-medium' }>{ row.brandName ? row.brandName : '--' }</span>;
      }
    }
  },
  {
    field: 'currencyCode', title: '货币代码', minWidth: 'auto', align: 'center',
    slots: {
      default({ row }: any) {
        return <span class={ 'font-medium' }>{ row.currencyCode ? row.currencyCode : '--' }</span>;
      }
    }
  },
  {
    field: 'status', title: '状 态', minWidth: 'auto', align: 'center',
    slots: {
      default({ row }: any) {
        return (
            <el-tag
                class="font-medium"
                type={ row.status === 1 ? 'success' : 'danger' }   // 动态绑定 type
            >
              { row.status === 1 ? '启用' : '暂停' }
            </el-tag>
        );
      }
    }
  },
  {
    field: 'platform', title: '平 台', minWidth: 'auto', align: 'center',
    slots: {
      default({ row }: any) {
        return <span class={ 'font-medium' }>{ row.platform ? row.platform : '--' }</span>;
      }
    }
  },
  {
    field: 'line', title: '线 路', minWidth: 'auto', align: 'center',
    slots: {
      default({ row }: any) {
        return <span class={ 'font-medium' }>{ row.line ? row.line : '--' }</span>;
      }
    }
  },
  {
    field: 'ipaddress', title: 'IP地址', minWidth: 'auto', align: 'center',
    slots: {
      default({ row }: any) {
        return <span class={ 'font-medium' }>{ row.ipaddress ? row.ipaddress : '--' }</span>;
      }
    }
  },
  {
    field: 'belongsCompany', title: '关联公司', minWidth: 'auto', align: 'center',
    slots: {
      default({ row }: any) {
        const company = companySelect.value.find(c => c.id === row.belongsCompany);
        return <span class="font-medium">{ company ? company.company : '--' }</span>;
      }
    }
  },
  {
    field: 'company', title: '公司名称', width: 'auto', align: 'center',
    slots: {
      default({ row }: any) {
        return <span class={ 'font-medium' }>{ row.company ? row.company : '--' }</span>;
      }
    }
  },
  {
    field: 'companyEnglishName', title: '公司英文名称', minWidth: 'auto', align: 'center',
    slots: {
      default({ row }: any) {
        return <span class={ 'font-medium' }>{ row.companyEnglishName ? row.companyEnglishName : '--' }</span>;
      }
    }
  },
  {
    field: 'address', title: '公司地址', minWidth: 'auto', align: 'center',
    slots: {
      default({ row }: any) {
        return <span class={ 'font-medium' }>{ row.address ? row.address : '--' }</span>;
      }
    }
  },
  {
    field: 'juridicalPerson', title: '法 人', minWidth: 'auto', align: 'center',
    slots: {
      default({ row }: any) {
        return <span class={ 'font-medium' }>{ row.juridicalPerson ? row.juridicalPerson : '--' }</span>;
      }
    }
  },
  {
    field: 'juridicalPersonCreditCard', title: '法人信用卡', minWidth: 'auto', align: 'center',
    slots: {
      default({ row }: any) {
        return <span
            class={ 'font-medium' }>{ row.juridicalPersonCreditCard ? row.juridicalPersonCreditCard : '--' }</span>;
      }
    }
  },
  {
    field: 'juridicalPersonCreditCardAddress', title: '法人信用卡地址', minWidth: 'auto', align: 'center',
    slots: {
      default({ row }: any) {
        return <span
            class={ 'font-medium' }>{ row.juridicalPersonCreditCardAddress ? row.juridicalPersonCreditCardAddress : '--' }</span>;
      }
    }
  },
  {
    field: 'receivablesAccount', title: '收款账户', minWidth: 'auto', align: 'center',
    slots: {
      default({ row }: any) {
        return <span class={ 'font-medium' }>{ row.receivablesAccount ? row.receivablesAccount : '--' }</span>;
      }
    }
  },
  {
    field: 'receivablesAccountCompany', title: '收款账户公司', minWidth: 'auto', align: 'center',
    slots: {
      default({ row }: any) {
        return <span
            class={ 'font-medium' }>{ row.receivablesAccountCompany ? row.receivablesAccountCompany : '--' }</span>;
      }
    }
  },
  {
    field: 'vatNumber', title: 'VAT税号', minWidth: 'auto', align: 'center',
    slots: {
      default({ row }: any) {
        return <span class={ 'font-medium' }>{ row.vatNumber ? row.vatNumber : '--' }</span>;
      }
    }
  },
  {
    field: 'vatCompany', title: 'VAT公司', minWidth: 'auto', align: 'center',
    slots: {
      default({ row }: any) {
        return <span class={ 'font-medium' }>{ row.vatCompany ? row.vatCompany : '--' }</span>;
      }
    }
  },
  {
    field: 'shopPhoneAndName', title: '主账户电话', minWidth: 'auto', align: 'center',
    slots: {
      default({ row }: any) {
        return <span class={ 'font-medium' }>{ row.shopPhoneAndName !== null ? row.shopPhoneAndName : '--' }</span>;
      }
    }
  },
  {
    field: 'shopEmail', title: '主账户邮箱', minWidth: 'auto', align: 'center',
    slots: {
      default({ row }: any) {
        return <span class={ 'font-medium' }>{ row.shopEmail ? row.shopEmail : '--' }</span>;
      }
    }
  },
  {
    field: 'subShopPhoneAndName', title: '子账户电话', minWidth: 'auto', align: 'center',
    slots: {
      default({ row }: any) {
        return <span class={ 'font-medium' }>{ row.subShopPhoneAndName ? row.subShopPhoneAndName : '--' }</span>;
      }
    }
  },
  {
    field: 'subShopEmail', title: '子账户邮箱', minWidth: 'auto', align: 'center',
    slots: {
      default({ row }: any) {
        return <span class={ 'font-medium' }>{ row.subShopEmail ? row.subShopEmail : '--' }</span>;
      }
    }
  }
];

export const historyColumns: any = [
  { type: 'seq', title: '序 号', width: 60, align: 'center', fixed: 'left' },
  {
    field: 'operatorName', title: '运 营', minWidth: 'auto', align: 'center', fixed: 'left',
    slots: {
      default({ row }: any) {
        return <span class={ 'font-medium' }>{ row.operatorName ? row.operatorName : '--' }</span>;
      }
    }
  },
  {
    field: 'platformNumber', title: '店铺编号', minWidth: 'auto', align: 'center',
    slots: {
      default({ row }: any) {
        return <span class={ 'font-medium' }>{ row.platformNumber ? row.platformNumber : '--' }</span>;
      }
    }
  },
  {
    field: 'platformName', title: '店铺名称', minWidth: 'auto', align: 'center',
    slots: {
      default({ row }: any) {
        return <span class={ 'font-medium' }>{ row.platformName ? row.platformName : '--' }</span>;
      }
    }
  },
  {
    field: 'country', title: '国 家', minWidth: 'auto', align: 'center',
    slots: {
      default({ row }: any) {
        const country = countryInfoStore.countries.find(c => c.name === row.country);
        const color = country ? country.color : '#3875F6';
        return <el-tag effect="plain" round
                       style={ { color: color, borderColor: color } }>{ row.country ? row.country : '--' }</el-tag>;
      }
    }
  },
  {
    field: 'brandName', title: '品牌名称', minWidth: 'auto', align: 'center',
    slots: {
      default({ row }: any) {
        return <span class={ 'font-medium' }>{ row.brandName ? row.brandName : '--' }</span>;
      }
    }
  },
  {
    field: 'currencyCode', title: '货币代码', minWidth: 'auto', align: 'center',
    slots: {
      default({ row }: any) {
        return <span class={ 'font-medium' }>{ row.currencyCode ? row.currencyCode : '--' }</span>;
      }
    }
  },
  {
    field: 'status', title: '状 态', minWidth: 'auto', align: 'center',
    slots: {
      default({ row }: any) {
        return (
            <el-tag
                class="font-medium"
                type={ row.status === 1 ? 'success' : 'danger' }   // 动态绑定 type
            >
              { row.status === 1 ? '启用' : '暂停' }
            </el-tag>
        );
      }
    }
  },
  {
    field: 'platform', title: '平 台', minWidth: 'auto', align: 'center',
    slots: {
      default({ row }: any) {
        return <span class={ 'font-medium' }>{ row.platform ? row.platform : '--' }</span>;
      }
    }
  },
  {
    field: 'line', title: '线 路', minWidth: 'auto', align: 'center',
    slots: {
      default({ row }: any) {
        return <span class={ 'font-medium' }>{ row.line ? row.line : '--' }</span>;
      }
    }
  },
  {
    field: 'ipaddress', title: 'IP地址', minWidth: 'auto', align: 'center',
    slots: {
      default({ row }: any) {
        return <span class={ 'font-medium' }>{ row.ipaddress ? row.ipaddress : '--' }</span>;
      }
    }
  },
  {
    field: 'company', title: '公司名称', minWidth: 'auto', align: 'center',
    slots: {
      default({ row }: any) {
        return <span class={ 'font-medium' }>{ row.company ? row.company : '--' }</span>;
      }
    }
  },
  {
    field: 'companyEnglishName', title: '公司英文名称', minWidth: 'auto', align: 'center',
    slots: {
      default({ row }: any) {
        return <span class={ 'font-medium' }>{ row.companyEnglishName ? row.companyEnglishName : '--' }</span>;
      }
    }
  },
  {
    field: 'address', title: '公司地址', minWidth: 'auto', align: 'center',
    slots: {
      default({ row }: any) {
        return <span class={ 'font-medium' }>{ row.address ? row.address : '--' }</span>;
      }
    }
  },
  {
    field: 'juridicalPerson', title: '法 人', minWidth: 'auto', align: 'center',
    slots: {
      default({ row }: any) {
        return <span class={ 'font-medium' }>{ row.juridicalPerson ? row.juridicalPerson : '--' }</span>;
      }
    }
  },
  {
    field: 'juridicalPersonCreditCard', title: '法人信用卡', minWidth: 'auto', align: 'center',
    slots: {
      default({ row }: any) {
        return <span
            class={ 'font-medium' }>{ row.juridicalPersonCreditCard ? row.juridicalPersonCreditCard : '--' }</span>;
      }
    }
  },
  {
    field: 'juridicalPersonCreditCardAddress', title: '法人信用卡地址', minWidth: 'auto', align: 'center',
    slots: {
      default({ row }: any) {
        return <span
            class={ 'font-medium' }>{ row.juridicalPersonCreditCardAddress ? row.juridicalPersonCreditCardAddress : '--' }</span>;
      }
    }
  },
  {
    field: 'receivablesAccount', title: '收款账户', minWidth: 'auto', align: 'center',
    slots: {
      default({ row }: any) {
        return <span class={ 'font-medium' }>{ row.receivablesAccount ? row.receivablesAccount : '--' }</span>;
      }
    }
  },
  {
    field: 'receivablesAccountCompany', title: '收款账户公司', minWidth: 'auto', align: 'center',
    slots: {
      default({ row }: any) {
        return <span
            class={ 'font-medium' }>{ row.receivablesAccountCompany ? row.receivablesAccountCompany : '--' }</span>;
      }
    }
  },
  {
    field: 'vatNumber', title: 'VAT税号', minWidth: 'auto', align: 'center',
    slots: {
      default({ row }: any) {
        return <span class={ 'font-medium' }>{ row.vatNumber ? row.vatNumber : '--' }</span>;
      }
    }
  },
  {
    field: 'vatCompany', title: 'VAT公司', minWidth: 'auto', align: 'center',
    slots: {
      default({ row }: any) {
        return <span class={ 'font-medium' }>{ row.vatCompany ? row.vatCompany : '--' }</span>;
      }
    }
  },
  {
    field: 'create_datetime', title: '创建时间', minWidth: 'auto', align: 'center',
    slots: {
      default({ row }: any) {
        return <span class={ 'font-medium' }>{ row.create_datetime ? row.create_datetime : '--' }</span>;
      }
    }
  },
  {
    field: 'approveNum', title: '审批单号', minWidth: 'auto', align: 'center',
    slots: {
      default({ row }: any) {
        return <span class={ 'font-medium' }>{ row.approveNum ? row.approveNum : '--' }</span>;
      }
    }
  },
  {
    field: 'shopPhoneAndName', title: '主账户电话', minWidth: 'auto', align: 'center',
    slots: {
      default({ row }: any) {
        return <span class={ 'font-medium' }>{ row.shopPhoneAndName !== null ? row.shopPhoneAndName : '--' }</span>;
      }
    }
  },
  {
    field: 'shopEmail', title: '主账户邮箱', minWidth: 'auto', align: 'center',
    slots: {
      default({ row }: any) {
        return <span class={ 'font-medium' }>{ row.shopEmail ? row.shopEmail : '--' }</span>;
      }
    }
  },
  {
    field: 'subShopPhoneAndName', title: '子账户电话', minWidth: 'auto', align: 'center',
    slots: {
      default({ row }: any) {
        return <span class={ 'font-medium' }>{ row.subShopPhoneAndName ? row.subShopPhoneAndName : '--' }</span>;
      }
    }
  },
  {
    field: 'subShopEmail', title: '子账户邮箱', minWidth: 'auto', align: 'center',
    slots: {
      default({ row }: any) {
        return <span class={ 'font-medium' }>{ row.subShopEmail ? row.subShopEmail : '--' }</span>;
      }
    }
  }
];

export const computerColumns: any = [
  { type: 'seq', title: '序 号', width: 60, align: 'center', fixed: 'left' },
  {
    field: 'operatorName', title: '使用人', minWidth: 'auto', align: 'center',
    slots: {
      default({ row }: any) {
        return <span class={ 'font-medium' }>{ row.operatorName ? row.operatorName : '--' }</span>;
      }
    }
  },
  {
    field: 'computerNumber', title: '电脑编号', minWidth: 'auto', align: 'center',
    slots: {
      default({ row }: any) {
        return <span class={ 'font-medium' }>{ row.computerNumber ? row.computerNumber : '--' }</span>;
      }
    }
  },
  {
    field: 'computerType', title: '计算机类型', minWidth: 'auto', align: 'center',
    slots: {
      default({ row }: any) {
        return <span class={ 'font-medium' }>{ row.computerType ? row.computerType : '--' }</span>;
      }
    }
  },
  {
    field: 'station', title: '位 置', minWidth: 'auto', align: 'center',
    slots: {
      default({ row }: any) {
        return <span class={ 'font-medium' }>{ row.station ? row.station : '--' }</span>;
      }
    }
  },
  {
    field: 'ipaddress', title: 'IP地址', minWidth: 'auto', align: 'center',
    slots: {
      default({ row }: any) {
        return <span class={ 'font-medium' }>{ row.ipaddress ? row.ipaddress : '--' }</span>;
      }
    }
  },
  {
    field: 'macaddress', title: 'MAC地址', minWidth: 'auto', align: 'center',
    slots: {
      default({ row }: any) {
        return <span class={ 'font-medium' }>{ row.macaddress ? row.macaddress : '--' }</span>;
      }
    }
  }
];

export const shopInfoColumns = [
  { type: 'seq', title: '序 号', width: 65, align: 'center', fixed: 'left' },
  {
    field: 'operatorName', title: '运 营', minWidth: 'auto', align: 'center', fixed: 'left',
    slots: {
      default({ row }: any) {
        return <span class={ 'font-medium' }>{ row.operatorName ? row.operatorName : '--' }</span>;
      }
    }
  },
  {
    field: 'platformNumber', title: '店铺编号', minWidth: 'auto', align: 'center',
    slots: { default: 'platformNumber' }
  },
  {
    field: 'platformName', title: '店铺名称', minWidth: 'auto', align: 'center',
    slots: {
      default({ row }: any) {
        return <span class={ 'font-medium' }>{ row.platformName ? row.platformName : '--' }</span>;
      }
    }
  },
  {
    field: 'countComputer', title: '电脑数量', minWidth: 'auto', align: 'center',
    slots: {
      default({ row }: any) {
        return <span class={ 'font-medium' }>{ row.countComputer ? row.countComputer : '--' }</span>;
      }
    }
  },
  {
    field: 'country', title: '国 家', minWidth: 'auto', align: 'center',
    slots: {
      default({ row }: any) {
        const country = countryInfoStore.countries.find(c => c.name === row.country);
        const color = country ? country.color : '#3875F6';
        return <el-tag effect="plain" round
                       style={ { color: color, borderColor: color } }>{ row.country ? row.country : '--' }</el-tag>;
      }
    }
  },
  {
    field: 'brandName', title: '品牌名称', minWidth: 'auto', align: 'center',
    slots: {
      default({ row }: any) {
        return <span class={ 'font-medium' }>{ row.brandName ? row.brandName : '--' }</span>;
      }
    }
  },
  {
    field: 'currencyCode', title: '货币代码', minWidth: 'auto', align: 'center',
    slots: {
      default({ row }: any) {
        return <span class={ 'font-medium' }>{ row.currencyCode ? row.currencyCode : '--' }</span>;
      }
    }
  },
  {
    field: 'status', title: '状 态', minWidth: 'auto', align: 'center',
    slots: {
      default({ row }: any) {
        return (
            <el-tag
                class="font-medium"
                type={ row.status === 1 ? 'success' : 'danger' }   // 动态绑定 type
            >
              { row.status === 1 ? '启用' : '暂停' }
            </el-tag>
        );
      }
    }
  },
  {
    field: 'platform', title: '平 台', minWidth: 'auto', align: 'center',
    slots: {
      default({ row }: any) {
        return <span class={ 'font-medium' }>{ row.platform ? row.platform : '--' }</span>;
      }
    }
  },
  {
    field: 'line', title: '线 路', minWidth: 'auto', align: 'center',
    slots: {
      default({ row }: any) {
        return <span class={ 'font-medium' }>{ row.line ? row.line : '--' }</span>;
      }
    }
  },
  {
    field: 'ipaddress', title: 'IP地址', minWidth: 'auto', align: 'center',
    slots: {
      default({ row }: any) {
        return <span class={ 'font-medium' }>{ row.ipaddress ? row.ipaddress : '--' }</span>;
      }
    }
  },
  {
    field: 'belongsCompany', title: '关联公司', minWidth: 'auto', align: 'center',
    slots: {
      default({ row }: any) {
        const company = companySelect.value.find(c => c.id === row.belongsCompany);
        return <span class="font-medium">{ company ? company.company : '--' }</span>;
      }
    }
  },
  {
    field: 'company', title: '公司名称', width: 'auto', align: 'center',
    slots: {
      default({ row }: any) {
        return <span class={ 'font-medium' }>{ row.company ? row.company : '--' }</span>;
      }
    }
  },
  {
    field: 'companyEnglishName', title: '公司英文名称', minWidth: 'auto', align: 'center',
    slots: {
      default({ row }: any) {
        return <span class={ 'font-medium' }>{ row.companyEnglishName ? row.companyEnglishName : '--' }</span>;
      }
    }
  },
  {
    field: 'address', title: '公司地址', minWidth: 'auto', align: 'center',
    slots: {
      default({ row }: any) {
        return <span class={ 'font-medium' }>{ row.address ? row.address : '--' }</span>;
      }
    }
  },
  {
    field: 'juridicalPerson', title: '法 人', minWidth: 'auto', align: 'center',
    slots: {
      default({ row }: any) {
        return <span class={ 'font-medium' }>{ row.juridicalPerson ? row.juridicalPerson : '--' }</span>;
      }
    }
  },
  {
    field: 'juridicalPersonCreditCard', title: '法人信用卡', minWidth: 'auto', align: 'center',
    slots: {
      default({ row }: any) {
        return <span
            class={ 'font-medium' }>{ row.juridicalPersonCreditCard ? row.juridicalPersonCreditCard : '--' }</span>;
      }
    }
  },
  {
    field: 'juridicalPersonCreditCardAddress', title: '法人信用卡地址', minWidth: 'auto', align: 'center',
    slots: {
      default({ row }: any) {
        return <span
            class={ 'font-medium' }>{ row.juridicalPersonCreditCardAddress ? row.juridicalPersonCreditCardAddress : '--' }</span>;
      }
    }
  },
  {
    field: 'receivablesAccount', title: '收款账户', minWidth: 'auto', align: 'center',
    slots: {
      default({ row }: any) {
        return <span class={ 'font-medium' }>{ row.receivablesAccount ? row.receivablesAccount : '--' }</span>;
      }
    }
  },
  {
    field: 'receivablesAccountCompany', title: '收款账户公司', minWidth: 'auto', align: 'center',
    slots: {
      default({ row }: any) {
        return <span
            class={ 'font-medium' }>{ row.receivablesAccountCompany ? row.receivablesAccountCompany : '--' }</span>;
      }
    }
  },
  {
    field: 'vatNumber', title: 'VAT税号', minWidth: 'auto', align: 'center',
    slots: {
      default({ row }: any) {
        return <span class={ 'font-medium' }>{ row.vatNumber ? row.vatNumber : '--' }</span>;
      }
    }
  },
  {
    field: 'vatCompany', title: 'VAT公司', minWidth: 'auto', align: 'center',
    slots: {
      default({ row }: any) {
        return <span class={ 'font-medium' }>{ row.vatCompany ? row.vatCompany : '--' }</span>;
      }
    }
  },
  {
    field: 'shopPhoneAndName', title: '主账户电话', minWidth: 'auto', align: 'center',
    slots: {
      default({ row }: any) {
        return <span class={ 'font-medium' }>{ row.shopPhoneAndName !== null ? row.shopPhoneAndName : '--' }</span>;
      }
    }
  },
  {
    field: 'shopEmail', title: '主账户邮箱', minWidth: 'auto', align: 'center',
    slots: {
      default({ row }: any) {
        return <span class={ 'font-medium' }>{ row.shopEmail ? row.shopEmail : '--' }</span>;
      }
    }
  },
  {
    field: 'subShopPhoneAndName', title: '子账户电话', minWidth: 'auto', align: 'center',
    slots: {
      default({ row }: any) {
        return <span class={ 'font-medium' }>{ row.subShopPhoneAndName ? row.subShopPhoneAndName : '--' }</span>;
      }
    }
  },
  {
    field: 'subShopEmail', title: '子账户邮箱', minWidth: 'auto', align: 'center',
    slots: {
      default({ row }: any) {
        return <span class={ 'font-medium' }>{ row.subShopEmail ? row.subShopEmail : '--' }</span>;
      }
    }
  }
]

